@@ -16,6 +16,9 @@ mod access_token_store;
 mod oauth;
 pub mod requests;
 pub mod types;
+// Note we are using a very hacked slimmed&vendored version of serde_qs to allow serializing Vec in form of
+// vec=foo&vec=bar&vec=baz instead of regular serde_qs vec[1]=foo&vec[2]=bar&vec[3]=baz
+mod serde_qs;
 
 /// Scoop.it API endpoints.
 ///
@@ -211,8 +214,8 @@ impl TryFrom<AccessTokenResponse> for AccessToken {
 #[cfg(test)]
 mod tests {
     use crate::{
-        GetProfileRequest, GetTopicRequest, ScoopitAPIClient, SearchRequest, SearchRequestType,
-        TestRequest,
+        GetProfileRequest, GetTopicOrder, GetTopicRequest, ScoopitAPIClient, SearchRequest,
+        SearchRequestType, TestRequest,
     };
 
     async fn get_client() -> ScoopitAPIClient {
@@ -252,6 +255,32 @@ mod tests {
             .await
             .unwrap();
         println!("{:#?}", topic);
+
+        let topic = get_client()
+            .await
+            .get(GetTopicRequest {
+                url_name: Some("sports-and-performance-psychology".to_string()),
+                order: Some(GetTopicOrder::User),
+                ..Default::default()
+            })
+            .await
+            .unwrap();
+        println!("{:#?}", topic);
+    }
+
+    #[tokio::test]
+    async fn get_topic_with_tags() {
+        let topic = get_client()
+            .await
+            .get(GetTopicRequest {
+                url_name: Some("best-of-photojournalism".to_string()),
+                order: Some(GetTopicOrder::Tag),
+                tag: Some(vec!["afghanistan".to_string()]),
+                ..Default::default()
+            })
+            .await
+            .unwrap();
+        println!("{:#?}", topic);
     }
 
     #[tokio::test]
